@@ -1,5 +1,5 @@
 package HackaMol::Roles::PhysVecMVRRole;
-$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.034';
+$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.035';
 # ABSTRACT: Provides the core of HackaMol Atom and Molecule classes.
 use Math::Vector::Real;
 use Math::Trig;
@@ -7,7 +7,7 @@ use Math::Trig;
 #use Moose::Util::TypeConstraints;
 use Moose::Role;
 use Carp;
-use Data::Structure::Util qw (unbless);
+#use Data::Structure::Util qw (unbless);
 #use MooseX::Storage;
 
 #with Storage( 'format' => 'JSON', 'io' => 'File' );
@@ -342,7 +342,7 @@ HackaMol::Roles::PhysVecMVRRole - Provides the core of HackaMol Atom and Molecul
 
 =head1 VERSION
 
-version 0.034
+version 0.035
 
 =head1 SYNOPSIS
 
